@@ -113,7 +113,8 @@ sub configurator {
 	$cfg->{user}->{fullname} = ::runtimeinfo("short");
     }
     else {
-	$cfg->{user}->{name} = $ENV{USER} || $ENV{LOGNAME} || lc(getlogin());
+	$cfg->{user}->{name} = $ENV{USER} || $ENV{LOGNAME}
+	  || lc(getlogin()) || getpwuid($<) || "chordpro";
 	$cfg->{user}->{fullname} = eval { (getpwuid($<))[6] } || "";
     }
 
@@ -961,6 +962,9 @@ sub default_config() {
       "chords-canonical" : false,
       // If false, chorus labels are used as tags.
       "choruslabels" : true,
+      // Substitute Unicode sharp/flats in chord names.
+      // Will fallback to ChordProSymbols the font doesn't have the glyphs.
+      "truesf" : false,
     },
 
     // Metadata.
@@ -1121,6 +1125,7 @@ sub default_config() {
             "handler"  : "abc2image",
             "config"   : "default", // or "none", or "myformat.fmt"
             "preamble" : [],
+            "preprocess" : { "abc" : [], "svg" : [] },
         },
         "ly" : {
             "type"     : "image",
@@ -1185,6 +1190,7 @@ sub default_config() {
 	  "title"  : 1.2,
 	  "lyrics" : 1.2,
 	  "chords" : 1.2,
+	  "diagramchords" : 1.2,
 	  "grid"   : 1.2,
 	  "tab"    : 1.0,
 	  "toc"    : 1.4,
@@ -1295,7 +1301,8 @@ sub default_config() {
       "pagealign-songs" : 1,
 
       // Formats.
-      // Pages have two title elements and one footer element.
+      // Pages have two title elements and one footer element. They also
+      // can have a page of an existing PDF file as underlay (background).
       // Topmost is "title". It uses the "title" font as defined further below.
       // Second is "subtitle". It uses the "subtitle" font.
       // The "footer" uses the "footer" font.
@@ -1311,10 +1318,12 @@ sub default_config() {
       // title/subtitle fields. Don't try to add an artist page element.
 
       "formats" : {
-	  // Titles/Footers.
+  	  // Titles/Footers.
 
-	  // Titles/footers have 3 parts, which are printed left,
+  	  // Titles/footers have 3 parts, which are printed left,
 	  // centered and right.
+	  // For odd/even printing, the 1st background page is used
+	  // for left pages and the next page (if it exists) for right pages.
 	  // For even/odd printing, the order is reversed.
 
 	  // By default, a page has:
@@ -1324,6 +1333,8 @@ sub default_config() {
 	      "subtitle"  : [ "", "", "" ],
 	      // Footer is title -- page number.
 	      "footer"    : [ "%{title}", "", "%{page}" ],
+	      // Background page.
+	      "background" : "",
 	  },
 	  // The first page of a song has:
 	  "title" : {
@@ -1332,12 +1343,16 @@ sub default_config() {
 	      "subtitle"  : [ "", "%{subtitle}", "" ],
 	      // Footer with page number.
 	      "footer"    : [ "", "", "%{page}" ],
+	      // Background page.
+	      "background" : "",
 	  },
 	  // The very first output page is slightly different:
 	  "first" : {
 	      // It has title and subtitle, like normal 'first' pages.
 	      // But no footer.
 	      "footer"    : [ "", "", "" ],
+	      // Background page.
+	      "background" : "",
 	  },
       },
 
@@ -1533,6 +1548,16 @@ sub default_config() {
 	},
     },
 
+    // Settings for LaTeX backend.
+    "latex" : {
+        "template_include_path" : [ ],
+	"templates" :  {
+	    "songbook" : "songbook.tt",
+	    "comment" : "comment.tt",
+	    "image"   : "image.tt"
+	}
+    },
+
     // Settings for Text backend.
     "text" : {
 	// Style of chorus.
